==> igniteui-react-16.16.2.tgz: package/esm5/lib/CircularGradient.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CircularGradient = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CircularGradient, _super);
    function CircularGradient() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(CircularGradient.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CircularGradient.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.a.d = this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CircularGradient.prototype, "g", {
        get: function () {
            var ret_ = this.b.c("offset");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("offset", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CircularGradient.prototype, "f", {
        get: function () {
            var ret_ = this.b.c("color");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("color", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CircularGradient.prototype, "c", {
        get: function () {
            var ret_ = this.b.c("opacity");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("opacity", value_);
        },
        enumerable: false,
        configurable: true
    });
    CircularGradient.$t = markType(CircularGradient, 'CircularGradient', BaseElement.$);
    return CircularGradient;
}(BaseElement));
export { CircularGradient };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/CircularGradient.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CircularGradient = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CircularGradient, _super);
    function CircularGradient() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(CircularGradient.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CircularGradient.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.a.o = this.d;
        },
        enumerable: false,
        configurable: true
    });
    CircularGradient.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(CircularGradient.prototype, "g", {
        get: function () {
            var ret_ = this.b.n("offset");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("offset", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CircularGradient.prototype, "f", {
        get: function () {
            var ret_ = this.b.n("color");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("color", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CircularGradient.prototype, "c", {
        get: function () {
            var ret_ = this.b.n("opacity");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("opacity", value_);
        },
        enumerable: false,
        configurable: true
    });
    CircularGradient.$t = markType(CircularGradient, 'CircularGradient', BaseElement.$);
    return CircularGradient;
}(BaseElement));
export { CircularGradient };
